get_addresses: Get the list of addresses of the specified territory

Description Usage Arguments Details

View source: R/get_addresses.R

Description

Returns a data frame with information about territories in the specified region.

Usage

1

Arguments

id

a territory identifier from ATO_Id in get_territories

Details

The data frame contains the following variables


Amice13/drv documentation built on Dec. 17, 2021, 8:47 a.m.