View source: R/get_districts.R
Returns a data frame with IDs, names, shorts name and central localities of Ukrainian regions.
1 |
The data frame contains the following variables
Region_Id - a region identifier
Area_Num - a district number
Area_Center - a central locality of the district
Area_Desc - borders of the district
Area_OvkAdr - an address of the district election election commission
Area_OvkLocation - a place where the district election election commission is located
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.