get_drv_entites: Get the list of organizations of Ukrainian State Register of...

Description Usage Details

View source: R/get_drv_entities.R

Description

Returns a data frame with IDs of regions, IDs, names, numbers, addresses and contacts of entities of Ukrainian State Register of Voters

Usage

1

Details

The data frame contains the following variables


Amice13/drv documentation built on Dec. 17, 2021, 8:47 a.m.