get_polling_stations: Get the list of polling stations of the specified district

Description Usage Arguments Details

View source: R/get_polling_stations.R

Description

Returns a data frame with information about polling stations in the specified district.

Usage

1

Arguments

id

a district number from Area_Num in get_districts

Details

The data frame contains the following variables


Amice13/drv documentation built on Dec. 17, 2021, 8:47 a.m.