get_territories: Get the list of territories of the specified region

Description Usage Arguments Details

View source: R/get_territories.R

Description

Returns a data frame with information about territories in the specified region.

Usage

1

Arguments

id

a region identifier from Region_Id in get_regions

Details

The data frame contains the following variables


Amice13/drv documentation built on Dec. 17, 2021, 8:47 a.m.